<?php 
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Plugin;
use Elementor\Repeater;
use Elementor\Icons_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Typography;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow as Group_Control_Box_Shadow;
use Elementor\Modules\DynamicTags\Module as TagsModule;


class themesflat_options_elementor {
	public function __construct(){	
        add_action('elementor/documents/register_controls', [$this, 'themesflat_elementor_register_options'], 10);
        add_action('elementor/editor/before_enqueue_scripts', function() { wp_enqueue_script( 'elementor-preview-load', THEMESFLAT_LINK . 'js/elementor/elementor-preview-load.js', array( 'jquery' ), null, true );
        }, 10, 3);
    }

    public function themesflat_elementor_register_options($element){
        $post_id = $element->get_id();
        $post_type = get_post_type($post_id);

        if ( ($post_type !== 'post') && ($post_type !== 'portfolios') && ($post_type !== 'services') ) {
        	$this->themesflat_options_page_header($element);
            $this->themesflat_options_page_pagetitle($element);
            $this->themesflat_options_page_footer($element);
            $this->themesflat_options_page($element);          
        }
    }

    public function themesflat_get_menus(){
        $list = [];
        $menus = wp_get_nav_menus();
        $list[''] = esc_html__('Theme Setting','zev');
        foreach($menus as $menu){
            $list[$menu->slug] = $menu->name;
        }

        return $list;
    }

    public function themesflat_options_page_header($element) {
        // TF Header
        $element->start_controls_section(
            'themesflat_header_options',
            [
                'label' => esc_html__('TF Header', 'zev'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        // Logo
        $element->add_control(
            'site_logo',
            [
                'label'   => esc_html__( 'Custom Logo', 'zingbox' ),
                'type'    => Controls_Manager::MEDIA,
            ]
        );

        // Logo
        $element->add_control(
            'site_logo_sticky',
            [
                'label'   => esc_html__( 'Custom Logo Sticky', 'zingbox' ),
                'type'    => Controls_Manager::MEDIA,
            ]
        );

        $element->add_control(
            'style_header',
            [
                'label'     => esc_html__( 'Header Style', 'zev'),
                'type'      => Controls_Manager::SELECT,
                'default'   => '',
                'options'   => [
                	'' => esc_html__( 'Theme Setting', 'zev'),
                    'header-style1' => esc_html__( 'Header style 01', 'zev'),
                    'header-style2' => esc_html__( 'Header style 02', 'zev' ),
                    'header-style3' => esc_html__( 'Header style 03', 'zev' ),
                ],
            ]
        );

        $element->add_control(
            'nav_menu_header',
            [
                'label'     =>esc_html__( 'Select Menu', 'zev' ),
                'type'      =>  Controls_Manager::SELECT,
                'options'   => $this->themesflat_get_menus(),
            ]
        );

        $element->add_control(
            'menu_one_page',
            [
                'label' => esc_html__( 'Menu One Page', 'zev' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Yes', 'zev' ),
                'label_off' => esc_html__( 'No', 'zev' ),
                'return_value' => 1,
                'default' => 0,
            ]
        );

        $element->add_control(
            'header_bg',
            [
                'label' => esc_html__( 'Background Color', 'zev' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} #header' => 'background: {{VALUE}};',
                ],
            ]
        );

        $element->add_control(
            'header_sticky_bgcolor',
            [
                'label' => esc_html__( 'Sticky Background', 'zev' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .themesflat_header_wrap.header-sticky #header' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'style_header!' => 'header-style3',
                ],
            ]
        );

        $element->add_control(
            'header_sticky_color',
            [
                'label' => esc_html__( 'Sticky Color', 'zev' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header-sticky #mainnav > ul > li:not(.current-menu-parent) > a,{{WRAPPER}} .header-sticky #mainnav > ul > li:not(.current-menu-ancestor) > a, {{WRAPPER}} .header-sticky .header-modal-menu-left-btn .text, {{WRAPPER}} .header-sticky header .flat-information li, {{WRAPPER}} .header-sticky header .flat-information li a, {{WRAPPER}} .header-sticky #header .show-search a, {{WRAPPER}} .header-sticky #mainnav > ul > li.current-menu-item > a, .header-sticky #mainnav > ul > li a:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .header-sticky .header-modal-menu-left-btn .modal-menu-left-btn .line, {{WRAPPER}} .header-sticky .btn-menu:before, {{WRAPPER}} .header-sticky .btn-menu:after, {{WRAPPER}} .header-sticky .btn-menu span' => 'background: {{VALUE}};',
                ],
                'condition' => [
                    'style_header!' => 'header-style3',
                ],
            ]
        );

        //Extra Classes Header
        $element->add_control(
            'extra_classes_header',
            [
                'label'   => esc_html__( 'Extra Classes', 'zev' ),
                'type'    => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_page_pagetitle($element) {
        // TF Page Title
        $element->start_controls_section(
            'themesflat_pagetitle_options',
            [
                'label' => esc_html__('TF Page Title', 'zev'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );       

        $element->add_control(
            'hide_pagetitle',
            [
                'label'     => esc_html__( 'Hide Page Title', 'zev'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'block',
                'options'   => [
                    'none'       => esc_html__( 'Yes', 'zev'),
                    'block'      => esc_html__( 'No', 'zev'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} .page-title' => 'display: {{VALUE}};',
                ],
            ]
        ); 

        $element->add_control(
            'pagetitle_padding',
            [
                'label' => esc_html__( 'Padding', 'zev' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} .page-title' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        ); 

        $element->add_control(
            'pagetitle_margin',
            [
                'label' => esc_html__( 'Margin', 'zev' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} .page-title' => 'margin-top: {{TOP}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        );              

        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'pagetitle_bg',
                'label' => esc_html__( 'Background', 'zev' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .page-title',
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        );

        $element->add_control(
            'pagetitle_overlay_color',
            [
                'label' => esc_html__( 'Overlay Color', 'zev' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .page-title .overlay' => 'background: {{VALUE}}; opacity: 100%;filter: alpha(opacity=100);',
                ],
                'condition' => [ 'hide_pagetitle' => 'block' ]
            ]
        );

        //Extra Classes Page Title
        $element->add_control(
            'extra_classes_pagetitle',
            [
                'label'   => esc_html__( 'Extra Classes', 'zev' ),
                'type'    => Controls_Manager::TEXT,
                'label_block' => true,
                'separator' => 'before'
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_page_footer($element) {
        // TF Footer
        $element->start_controls_section(
            'themesflat_footer_options',
            [
                'label' => esc_html__('TF Footer', 'zev'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $element->add_control(
            'partner_box_heading',
            [
                'label'     => esc_html__( 'Partner Box', 'zev'),
                'type'      => Controls_Manager::HEADING,
            ]
        );

        $element->add_control(
            'hide_partner_box',
            [
                'label'     => esc_html__( 'Hide Partner Box', 'zev'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'block',
                'options'   => [
                    'none'       => esc_html__( 'Yes', 'zev'),
                    'block'      => esc_html__( 'No', 'zev'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} .themesflat-partner-box' => 'display: {{VALUE}};'
                ],
            ]
        );

        $element->add_control(
            'footer_heading',
            [
                'label'     => esc_html__( 'Footer', 'zev'),
                'type'      => Controls_Manager::HEADING,
            ]
        );       

        $element->add_control(
            'hide_footer',
            [
                'label'     => esc_html__( 'Hide Footer', 'zev'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'block',
                'options'   => [
                    'none'       => esc_html__( 'Yes', 'zev'),
                    'block'      => esc_html__( 'No', 'zev'),
                ],
                'selectors'  => [
                    '{{WRAPPER}} #footer' => 'display: {{VALUE}};',
                    '{{WRAPPER}} .info-footer' => 'display: {{VALUE}};' 
                ],
            ]
        );

        $element->add_control(
            'footer_padding',
            [
                'label' => esc_html__( 'Padding', 'zev' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} #footer' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
                'condition' => [ 'hide_footer' => 'block' ]
            ]
        );

        $element->end_controls_section();
    }

    public function themesflat_options_page($element) {
        // TF Page
        $element->start_controls_section(
            'themesflat_page_options',
            [
                'label' => esc_html__('TF Page', 'zev'),
                'tab' => Controls_Manager::TAB_SETTINGS,
            ]
        );

        $element->add_control(
            'main_content_heading',
            [
                'label'     => esc_html__( 'Main Content', 'zev'),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $element->add_control(
            'main_content_padding',
            [
                'label' => esc_html__( 'Padding', 'zev' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} #themesflat-content' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                ],
            ]
        ); 

        $element->add_control(
            'main_content_margin',
            [
                'label' => esc_html__( 'Margin', 'zev' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'allowed_dimensions' => [ 'top', 'bottom' ],
                'selectors' => [
                    '{{WRAPPER}} #themesflat-content' => 'margin-top: {{TOP}}{{UNIT}}; margin-bottom: {{BOTTOM}}{{UNIT}};',
                ],
            ]
        );

        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'body_bg',
                'label' => esc_html__( 'Background', 'zev' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .themesflat-boxed',
            ]
        );

        $element->end_controls_section();
    }
}

new themesflat_options_elementor();