<?php
class TFHeader_Widget_Free extends \Elementor\Widget_Base {

	public function get_name() {
        return 'tf-header-widget';
    }
    
    public function get_title() {
        return esc_html__( 'TF Header', 'themesflat-elementor' );
    }

    public function get_icon() {
        return 'eicon-nav-menu';
    }
    
    public function get_categories() {
        return [ 'themesflat_addons_header_footer' ];
    }

    public function get_style_depends(){
	    return ['tf-font-awesome','tf-regular','tf-style'];
	}
    public function get_script_depends() {
    	return ['jquery-easing','tf-main'];
  	}

    public function get_menus(){
        $list = [];
        $menus = wp_get_nav_menus();
        foreach($menus as $menu){
            $list[$menu->slug] = $menu->name;
        }

        return $list;
    }

	protected function register_controls() {
        // Start Tab Setting        
			$this->start_controls_section( 'section_tabs',
	            [
	                'label' => esc_html__('Header', 'themesflat-elementor'),
	            ]
	        );

	        $this->add_control(
				'logo',
				[
					'label' => esc_html__( 'Choose Logo', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'default' => [
						'url' => URL_THEMESFLAT_ADDONS_ELEMENTOR."assets/img/logo.png",
					],
				]
			);

			$this->add_control(
				'logo_second',
				[
					'label' => esc_html__( 'Choose Logo Second', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::MEDIA,
					'description' => esc_html__('Use for One Page Or Sticky Header', 'themesflat-elementor'),
					'default' => [
						'url' => "",
					],					
				]
			);
			

			$this->add_group_control(
				\Elementor\Group_Control_Image_Size::get_type(),
				[
					'name' => 'thumbnail_logo',
					'include' => [],
					'default' => 'medium',
				]
			);
			

			$this->add_responsive_control( 
	        	'logo_size',
				[
					'label' => esc_html__( 'Logo Size', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 0,
							'max' => 500,
							'step' => 1,
						]
					],
					'default' => [
						'unit' => 'px',
						'size' => 89,
					],
					'selectors' => [
						'{{WRAPPER}} #header #logo a' => 'width: {{SIZE}}{{UNIT}};',
						'{{WRAPPER}} #header #logo-mobi a' => 'width: {{SIZE}}{{UNIT}};',
					],
				]
			);

			$this->add_control(
	            'nav_menu',
	            [
	                'label'     =>esc_html__( 'Select menu', 'themesflat-elementor' ),
	                'type'      =>  \Elementor\Controls_Manager::SELECT,
	                'options'   => $this->get_menus(),
	            ]
			);

			$this->add_control( 
	        	'menu_anchor',
				[
					'label' => esc_html__( 'Menu Anchor', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Yes', 'themesflat-elementor' ),
					'label_off' => esc_html__( 'No', 'themesflat-elementor' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);
	        
			$this->end_controls_section();
        // /.End Tab Setting 

		// Start Layout
	        $this->start_controls_section( 'section_Layout',
	            [
	                'label' => esc_html__( 'Layout', 'themesflat-elementor' ),
	            ]
	        );

	        $this->add_control( 
	        	'header_style',
				[
					'label' => esc_html__( 'Header Style', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'default' => 'header-style2',
					'options' => [
						'header-style1' => esc_html__( 'Style 1', 'themesflat-elementor' ),
						'header-style2' => esc_html__( 'Style 2', 'themesflat-elementor' ),
						'header-style3' => esc_html__( 'Style 3', 'themesflat-elementor' ),
					],
				]
			);

			$this->add_control( 
	        	'header_absolute',
				[
					'label' => esc_html__( 'Header Absolute', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Yes', 'themesflat-elementor' ),
					'label_off' => esc_html__( 'No', 'themesflat-elementor' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);

	        $this->add_control( 
	        	'stretch_container',
				[
					'label' => esc_html__( 'Stretch Container', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Yes', 'themesflat-elementor' ),
					'label_off' => esc_html__( 'No', 'themesflat-elementor' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);

			$this->add_control( 
	        	'header_fixed',
				[
					'label' => esc_html__( 'Header Fixed', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Yes', 'themesflat-elementor' ),
					'label_off' => esc_html__( 'No', 'themesflat-elementor' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);

			$this->add_control( 
	        	'header_sticky',
				[
					'label' => esc_html__( 'Header Sticky', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Yes', 'themesflat-elementor' ),
					'label_off' => esc_html__( 'No', 'themesflat-elementor' ),
					'return_value' => 'yes',
					'default' => 'no',
					'condition' => [
						'header_fixed!' => 'yes',
					],
				]
			);			

			$this->add_control( 
	        	'header_search',
				[
					'label' => esc_html__( 'Search Box', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => esc_html__( 'Show', 'themesflat-elementor' ),
					'label_off' => esc_html__( 'Hide', 'themesflat-elementor' ),
					'return_value' => 'yes',
					'default' => 'no',
				]
			);

			$this->add_control( 
				'info_mail',
				[
					'label' => esc_html__( 'Info Mail', 'themesflat-elementor' ),
					'type'	=> \Elementor\Controls_Manager::TEXT,	
					'default' => 'contact@zview_creative.com',
					'label_block' => true,				
				]
			);

			$this->add_control( 
				'info_phone',
				[
					'label' => esc_html__( 'Info Phone', 'themesflat-elementor' ),
					'type'	=> \Elementor\Controls_Manager::TEXT,	
					'default' => '+(61) 3 8376 6284',
					'label_block' => true,	
					'condition' => [
						'header_style' => 'header-style3',
					],			
				]
			);

			$this->add_control( 
				'info_address',
				[
					'label' => esc_html__( 'Info Address', 'themesflat-elementor' ),
					'type'	=> \Elementor\Controls_Manager::TEXT,	
					'default' => 'Uruguay, El Pinar - Cda. de la Costa - Canelones',
					'label_block' => true,	
					'condition' => [
						'header_style' => 'header-style3',
					],	
				]
			);

			$this->add_control( 
				'button_text',
				[
					'label' => esc_html__( 'Button Text', 'themesflat-elementor' ),
					'type'	=> \Elementor\Controls_Manager::TEXT,	
					'default' => 'Hire Me Now',
					'label_block' => true,	
					'condition' => [
						'header_style' => 'header-style3',
					],	
				]
			);

			$this->add_control(
				'button_link',
				[
					'label' => esc_html__( 'Button Link', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::URL,
					'placeholder' => esc_html__( 'https://your-link.com', 'themesflat-elementor' ),
					'show_external' => true,
					'default' => [
						'url' => '#',
						'is_external' => true,
						'nofollow' => true,
					],
				]
			);
			        
        	$this->end_controls_section();    
	    // /.End Layout 

	    // Start Style
	        $this->start_controls_section( 'section_style',
	            [
	                'label' => esc_html__( 'Style', 'themesflat-elementor' ),
	                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
	            ]
	        );

			$this->add_control( 
				'color',
				[
					'label' => esc_html__( 'Color', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} #mainnav > ul > li > a' => 'color: {{VALUE}}',
						'{{WRAPPER}} .header-modal-menu-left-btn .text' => 'color: {{VALUE}}',	
						'{{WRAPPER}} header .flat-information li' => 'color: {{VALUE}}',
						'{{WRAPPER}} header .flat-information li a' => 'color: {{VALUE}}',
						'{{WRAPPER}} #header .show-search a' => 'color: {{VALUE}}',
						'{{WRAPPER}} #header .header-modal-menu-left-btn .modal-menu-left-btn .line' => 'background: {{VALUE}}',				
					],
				]
			);

			$this->add_control( 
				'color_hover',
				[
					'label' => esc_html__( 'Color Hover', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} #mainnav > ul > li > a:hover' => 'color: {{VALUE}}',	
						'{{WRAPPER}} header .flat-information li a:hover' => 'color: {{VALUE}}',
						'{{WRAPPER}} #header .show-search a:hover' => 'color: {{VALUE}}',
						'{{WRAPPER}} #mainnav > ul > li > a:after' => 'background: {{VALUE}}',
						'{{WRAPPER}} #mainnav > ul > li.current-menu-ancestor > a' => 'color: {{VALUE}}',						
						'{{WRAPPER}} #mainnav > ul > li.current-menu-ancestor > a:after' => 'background: {{VALUE}}',
						'{{WRAPPER}} #mainnav > ul > li.current-menu-parent > a' => 'color: {{VALUE}}',
						'{{WRAPPER}} #mainnav > ul > li.current-menu-parent > a:after' => 'background: {{VALUE}}',		
					],
				]
			);

			$this->add_responsive_control( 
				'header_padding',
				[
					'label' => esc_html__( 'Padding', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::DIMENSIONS,
					'size_units' => [ 'px', 'em' ],
					'selectors' => [
						'{{WRAPPER}} header.tf-widget-header .inner-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					],
				]
			);

			$this->add_group_control(
				\Elementor\Group_Control_Border::get_type(),
				[
					'name' => 'header_border',
					'label' => esc_html__( 'Border', 'themesflat-elementor' ),
					'selector' => '{{WRAPPER}} .tf-widget-header',
				]
			); 

			$this->add_control( 
				'background_header',
				[
					'label' => esc_html__( 'Background', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .tf-widget-header' => 'background: {{VALUE}}',				
					],
				]
			);

			$this->add_control( 
				'background_sticky',
				[
					'label' => esc_html__( 'Background Sticky', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .tf-widget-header.header-sticky' => 'background: {{VALUE}}',				
					],
				]
			);

			$this->add_control( 
				'color_sticky',
				[
					'label' => esc_html__( 'Color Sticky', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .tf-widget-header.header-sticky #mainnav > ul > li > a' => 'color: {{VALUE}}',
						'{{WRAPPER}} .tf-widget-header.header-sticky .flat-information li a' => 'color: {{VALUE}}',
						'{{WRAPPER}} #header.tf-widget-header.header-sticky .header-modal-menu-left-btn .modal-menu-left-btn .line' => 'background: {{VALUE}}',
						'{{WRAPPER}} #header.tf-widget-header.header-sticky .btn-menu:before, #header.tf-widget-header.header-sticky .btn-menu:after, #header.tf-widget-header.header-sticky .btn-menu span' => 'background: {{VALUE}}',		
					],
				]
			);

			$this->add_control( 
				'color_hover_sticky',
				[
					'label' => esc_html__( 'Color Hover Sticky', 'themesflat-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
					'default' => '#eb6d2f',
					'selectors' => [
						'{{WRAPPER}} .tf-widget-header.header-sticky #mainnav > ul > li > a.active' => 'color: {{VALUE}}',						
						'{{WRAPPER}} .tf-widget-header #mainnav-mobi > ul > li > a.active' => 'color: {{VALUE}}',
						'{{WRAPPER}} .tf-widget-header.header-sticky #mainnav > ul > li.current-menu-parent > a' => 'color: {{VALUE}}',
						'{{WRAPPER}} .tf-widget-header.header-sticky #mainnav > ul > li.current-menu-ancestor > a' => 'color: {{VALUE}}',
						'{{WRAPPER}} .tf-widget-header.header-sticky #mainnav > ul > li > a:hover' => 'color: {{VALUE}}',
					],
				]
			);
			        
        	$this->end_controls_section();    
	    // /.End Style 
	}

	protected function render($instance = []) {
		$settings = $this->get_settings_for_display();

		$header_sticky = $header_fixed = $menu_anchor = '';

		if ($settings['header_fixed'] == 'no') {
		    if ($settings['header_sticky']) {
		    	$header_sticky = 'header_sticky_yes';
		    }
	    }

		if ($settings['header_fixed'] == 'yes') {
			$header_fixed = 'header_fixed_yes';
		}

		if ($settings['menu_anchor'] == 'yes') {
			$menu_anchor = 'anchor-menu';
		}

		$this->add_render_attribute( 'tf_header_wrapper', ['id' => "header", 'class' => ['tf-widget-header', 'header', $settings['header_style'], $header_sticky, $header_fixed, $menu_anchor ], 'data-tabid' => $this->get_id()] );	
		
		$logo_site =  \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['logo']['id'], 'thumbnail_logo', $settings );
		$logo_second = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $settings['logo_second']['id'], 'thumbnail_logo', $settings );

		$stretch_container_class = '';
		if ($settings['stretch_container'] == 'yes') {
			$stretch_container_class = 'tf-container-fluid';
		}	

		$target = $settings['button_link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['button_link']['nofollow'] ? ' rel="nofollow"' : '';
		
		$args = array(
	        'menu'            => $settings['nav_menu'],
	        'container'       => false,
	        'container_class' => '',
	        'container_id'    => '',
	        'menu_class'      => 'menu',
	        'menu_id'         => '',
	        'echo'            => false,
	        'fallback_cb'     => 'wp_page_menu',
	        'before'          => '',
	        'after'           => '',
	        'link_before'     => '',
	        'link_after'      => '',
	        'items_wrap'      => '<ul id="%1$s" class="%2$s">%3$s</ul>',
	        'item_spacing'    => 'preserve',
	        'depth'           => 0,
	        'walker'          => '',
	        'theme_location'  => '',
	    );

		if ($settings['header_style'] == 'header-style3'){
		    $args = array(
		        'menu'            => $settings['nav_menu'],
		        'container'       => false,
		        'container_class' => '',
		        'container_id'    => '',
		        'menu_class'      => 'menu pagepiling-menu pagepiling-one-page-menu',
		        'menu_id'         => '',
		        'echo'            => false,
		        'fallback_cb'     => 'wp_page_menu',
		        'before'          => '',
		        'after'           => '',
		        'link_before'     => '',
		        'link_after'      => '',
		        'items_wrap'      => '<ul id="%1$s" class="%2$s">%3$s</ul>',
		        'item_spacing'    => 'preserve',
		        'depth'           => 0,
		        'walker'          => '',
		        'theme_location'  => '',
		    );

			function tf_pagepiling_add_menu_atts($atts){
			  $atts['data-menuanchor'] = str_replace("#","",$atts['href']);
			  return $atts;
			}
			add_filter('nav_menu_link_attributes', 'tf_pagepiling_add_menu_atts');		    
	    }

		?>
		<?php if ($settings['header_absolute'] == 'yes'): ?>
		<div class="header-absolute">
			<div class="themesflat_header_wrap">
		<?php endif; ?>

			<?php if ($settings['header_style'] == 'header-style3'): ?>		
				<header <?php echo $this->get_render_attribute_string('tf_header_wrapper'); ?>>
				    <div class="inner-header">  
				        <div class="container <?php echo esc_attr($stretch_container_class); ?>">
				            <div class="row">
				                <div class="col-md-12">		                    
									<div class="header-wrap clearfix">
									    <div class="header-ct-left">
									        <?php if ( $logo_site ) : ?>
											    <div id="logo" class="logo" >                  
											        <a href="<?php echo esc_url( home_url('/') ); ?>"  title="<?php bloginfo('name'); ?>">
										                <img class="site-logo site-logo-primary"  src="<?php echo esc_url($logo_site); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php if ( $logo_second ) : ?>
										                	<img class="site-logo site-logo-second"  src="<?php echo esc_url($logo_second); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php endif; ?>
											        </a>
											    </div>
											<?php else : ?>
											    <div id="logo" class="logo" >                  
											        <a href="<?php echo esc_url( home_url('/') ); ?>"  title="<?php bloginfo('name'); ?>">
										                <img class="site-logo site-logo-primary"  src="<?php echo esc_url($settings['logo']['url']); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php if ( $logo_second ) : ?>
										                	<img class="site-logo site-logo-second"  src="<?php echo esc_url($logo_second); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php endif; ?>
											        </a>
											    </div>        
											<?php endif; ?>
									    </div><!-- /.header-ct-left -->

									    <div class="header-ct-center">
									    	<?php if( $settings['info_mail'] != '' || $settings['info_phone'] != '' || $settings['info_address'] != '' ): ?>							        
										        <div class="header-text">
										            <ul class="flat-information">
										            	<?php if ($settings['info_mail'] != ''): ?>
										                <li><i class="far fa-envelope"></i><a href="mailto:<?php echo esc_attr($settings['info_mail']) ?>"><?php echo esc_attr($settings['info_mail']) ?></a></li>
										            	<?php endif; ?>

										            	<?php if ($settings['info_phone'] != ''): ?>
										                <li><i class="fas fa-phone"></i><a href="tel:<?php echo esc_attr($settings['info_phone']) ?>"><?php echo esc_attr($settings['info_phone']) ?></a></li>
										            	<?php endif; ?>

										            	<?php if ($settings['info_address'] != ''): ?>
										                <li><i class="fas fa-map-marker-alt"></i><span><?php echo esc_attr($settings['info_address']) ?></span></li>
										            	<?php endif; ?>
										            </ul>
										        </div>
										    	<?php endif; ?>	

										    	<?php if($settings['button_text'] != ''): ?>
										    	<a class="themesflat-button-gradient" href="<?php echo esc_url($settings['button_link']['url']); ?>" <?php echo esc_attr($target); ?> <?php echo esc_attr($nofollow); ?>><?php echo esc_html($settings['button_text']); ?></a>
										    	<?php endif; ?>						        

										        <?php if( $settings['header_search'] == 'yes' ): ?>
										        <div class="show-search">
					                                <a href="#"><i class="fa fa-search"></i></a> 
					                                <div class="submenu top-search widget_search">
					                                    <?php get_search_form(); ?>
					                                </div>        
					                            </div> 
					                        	<?php endif; ?>
									    </div>

									    <div class="header-ct-right">
									        <div class="header-modal-menu-right-btn">
									        	<div class="text"><?php echo esc_html__('Menu','themesflat-elementor') ?></div>
									            <div class="modal-menu-right-btn">
									                <div class="line line--1"></div>
									                <div class="line line--2"></div>
									                <div class="line line--3"></div>
									                <div class="line line--4"></div>
									            </div>
									        </div><!-- /.header-modal-menu-right-btn -->
									    </div><!-- /.header-ct-right -->
									</div>
								</div>
							</div>
						</div>
				    </div><!-- /.inner-header --> 
				    <div class="canvas-nav-wrap">
				        <div class="overlay-canvas-nav"><div class="canvas-menu-close"><span></span></div></div>
				        <div class="inner-canvas-nav">
				            <?php get_template_part( 'tpl/header/brand-mobile'); ?>
				            <nav id="mainnav_canvas" class="mainnav_canvas" role="navigation">
				                <?php echo wp_nav_menu($args);//wp_nav_menu( array( 'theme_location' => 'primary', 'fallback_cb' => 'themesflat_menu_fallback', 'container' => false ) ); ?>
				            </nav><!-- #mainnav_canvas -->  
				        </div>
				    </div><!-- /.canvas-nav-wrap -->

				    <?php $logo_site = themesflat_get_opt('site_logo'); ?>
				    <div class="modal-menu-right">
						<div class="modal-menu__backdrop"></div>
						<div class="modal-menu__body">
							<button class="modal-menu__close" type="button">
							    <i class="fa fa-times"></i>
							</button>
							<div class="modal-menu__panel">
								<div class="modal-menu__panel-header">
							        <div class="modal-menu__panel-title">
							        	<div class="header-modal-menu-left-btn">
							        		<div class="text">Menu</div>
								            <div class="modal-menu-right-btn">
								                <div class="line line--1"></div>
								                <div class="line line--2"></div>
								                <div class="line line--3"></div>
								                <div class="line line--4"></div>
								            </div>
							            </div>
							        </div>
							    </div>
							    <div class="modal-menu__panel-body">
									<div class="nav-wrap-secondary">				    
								        <div class="nav-wrap">
										    <nav id="mainnav" class="mainnav" role="navigation">
										        <?php
										            echo wp_nav_menu($args);//wp_nav_menu( array( 'theme_location' => 'primary', 'fallback_cb' => 'themesflat_menu_fallback', 'container' => false ) );
										        ?>
										    </nav><!-- #site-navigation -->  
										</div><!-- /.nav-wrap -->				    
									</div><!-- /.nav-wrap --> 
								</div>
								<div class="modal-menu__panel-footer">
									<?php if ( $logo_site ) : ?>
									    <div class="logo-panel" >                  
									        <a href="<?php echo esc_url( home_url('/') ); ?>"  title="<?php bloginfo('name'); ?>">
									            <?php if  (!empty($logo_site)) { ?>
									                <img class="site-logo"  src="<?php echo esc_url($logo_site); ?>" alt="<?php bloginfo('name'); ?>"/>
									            <?php } ?>
									        </a>
									    </div>          
									<?php endif; ?>
									<div class="socials-panel">
										<?php themesflat_render_social(); ?>
									</div>
								</div>
							</div>
						</div>
					</div> <!-- /.modal-menu-left --> 
				</header>
			<?php else: ?>
				<header <?php echo $this->get_render_attribute_string('tf_header_wrapper'); ?>>
				    <div class="inner-header">  
				        <div class="container <?php echo esc_attr($stretch_container_class); ?>">
				            <div class="row">
				                <div class="col-md-12">		                    
									<div class="header-wrap clearfix">
									    <div class="header-ct-left">
									        <?php if ( $logo_site ) : ?>
											    <div id="logo" class="logo" >                  
											        <a href="<?php echo esc_url( home_url('/') ); ?>"  title="<?php bloginfo('name'); ?>">
										                <img class="site-logo site-logo-primary"  src="<?php echo esc_url($logo_site); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php if ( $logo_second ) : ?>
										                	<img class="site-logo site-logo-second"  src="<?php echo esc_url($logo_second); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php endif; ?>
											        </a>
											    </div>
											<?php else : ?>
											    <div id="logo" class="logo" >                  
											        <a href="<?php echo esc_url( home_url('/') ); ?>"  title="<?php bloginfo('name'); ?>">
										                <img class="site-logo site-logo-primary"  src="<?php echo esc_url($settings['logo']['url']); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php if ( $logo_second ) : ?>
										                	<img class="site-logo site-logo-second"  src="<?php echo esc_url($logo_second); ?>" alt="<?php bloginfo('name'); ?>"/>
										                <?php endif; ?>
											        </a>
											    </div>        
											<?php endif; ?>
									    </div><!-- /.header-ct-left -->

									    <?php if ($settings['header_style'] == 'header-style2'): ?>
									    <div class="header-ct-center">
									        <div class="nav-wrap">
											    <nav id="mainnav" class="mainnav" role="navigation">
											        <?php
											            echo wp_nav_menu($args);//wp_nav_menu( array( 'theme_location' => 'primary', 'fallback_cb' => 'themesflat_menu_fallback', 'container' => false ) );
											        ?>
											    </nav><!-- #site-navigation -->  
											</div><!-- /.nav-wrap --> 
									    </div><!-- /.header-ct-center -->
									    <?php endif; ?>

									    <div class="header-ct-right">
									    	<?php if( $settings['info_mail'] != '' ): ?>							        
									        <div class="header-text">
									            <ul class="flat-information">
									                <li><i class="far fa-envelope"></i><a href="mailto:<?php echo esc_attr($settings['info_mail']) ?>"><?php echo esc_attr($settings['info_mail']) ?></a></li>
									            </ul>
									        </div>
									    	<?php endif; ?>							        

									        <?php if( $settings['header_search'] == 'yes' ): ?>
									        <div class="show-search">
				                                <a href="#"><i class="fa fa-search"></i></a> 
				                                <div class="submenu top-search widget_search">
				                                    <?php get_search_form(); ?>
				                                </div>        
				                            </div> 
				                        	<?php endif; ?>

									        <div class="header-modal-menu-left-btn">
									            <div class="modal-menu-left-btn">
									                <div class="line line--1"></div>
									                <div class="line line--2"></div>
									                <div class="line line--3"></div>
									                <div class="line line--4"></div>
									            </div>
									        </div><!-- /.header-modal-menu-left-btn -->

									        <div class="btn-menu">
				                                <span class="line-1"></span>
                                				<span class="line-2"></span>
				                            </div><!-- //mobile menu button -->
									    </div><!-- /.header-ct-right -->
									</div>
								</div>
							</div>
						</div>
				    </div><!-- /.inner-header --> 
				    <div class="canvas-nav-wrap">
				        <div class="overlay-canvas-nav"><div class="canvas-menu-close"><span></span></div></div>
				        <div class="inner-canvas-nav">
				            <?php get_template_part( 'tpl/header/brand-mobile'); ?>
				            <nav id="mainnav_canvas" class="mainnav_canvas" role="navigation">
				                <?php echo wp_nav_menu($args); //wp_nav_menu( array( 'theme_location' => 'primary', 'fallback_cb' => 'themesflat_menu_fallback', 'container' => false ) ); ?>
				            </nav><!-- #mainnav_canvas -->  
				        </div>
				    </div><!-- /.canvas-nav-wrap -->
				</header>
			<?php endif; ?>

		<?php if ($settings['header_absolute'] == 'yes'): ?>		
			</div>
		</div>
		<?php endif; 	
		
	}

}